import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AdministrativeUnitMemberConfig extends cdktf.TerraformMetaArguments {
    /**
     * The object ID of the administrative unit.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#administrative_unit_object_id AdministrativeUnitMember#administrative_unit_object_id}
     *
     * @stability stable
     */
    readonly administrativeUnitObjectId?: string;
    /**
     * The object ID of the member.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#member_object_id AdministrativeUnitMember#member_object_id}
     *
     * @stability stable
     */
    readonly memberObjectId?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#timeouts AdministrativeUnitMember#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: AdministrativeUnitMemberTimeouts;
}
/**
 * @stability stable
 */
export interface AdministrativeUnitMemberTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#create AdministrativeUnitMember#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#delete AdministrativeUnitMember#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#read AdministrativeUnitMember#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html#update AdministrativeUnitMember#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class AdministrativeUnitMemberTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string | undefined;
    /**
     * @stability stable
     */
    set create(value: string | undefined);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string | undefined;
    /**
     * @stability stable
     */
    set delete(value: string | undefined);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string | undefined;
    /**
     * @stability stable
     */
    set read(value: string | undefined);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string | undefined;
    /**
     * @stability stable
     */
    set update(value: string | undefined);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html azuread_administrative_unit_member}.
 *
 * @stability stable
 */
export declare class AdministrativeUnitMember extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/administrative_unit_member.html azuread_administrative_unit_member} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: AdministrativeUnitMemberConfig);
    private _administrativeUnitObjectId?;
    /**
     * @stability stable
     */
    get administrativeUnitObjectId(): string | undefined;
    /**
     * @stability stable
     */
    set administrativeUnitObjectId(value: string | undefined);
    /**
     * @stability stable
     */
    resetAdministrativeUnitObjectId(): void;
    /**
     * @stability stable
     */
    get administrativeUnitObjectIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _memberObjectId?;
    /**
     * @stability stable
     */
    get memberObjectId(): string | undefined;
    /**
     * @stability stable
     */
    set memberObjectId(value: string | undefined);
    /**
     * @stability stable
     */
    resetMemberObjectId(): void;
    /**
     * @stability stable
     */
    get memberObjectIdInput(): string | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    /**
     * @stability stable
     */
    get timeouts(): AdministrativeUnitMemberTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: AdministrativeUnitMemberTimeouts | undefined): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AdministrativeUnitMemberTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
